// java wrapper for vtkTensorProbeWidget object
//

package vtk;
import vtk.*;

public class vtkTensorProbeWidget extends vtkAbstractWidget
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetRepresentation_2(vtkTensorProbeRepresentation id0);
  public void SetRepresentation(vtkTensorProbeRepresentation id0)
    { SetRepresentation_2(id0); }

  private native long GetTensorProbeRepresentation_3();
  public vtkTensorProbeRepresentation GetTensorProbeRepresentation() {
    long temp = GetTensorProbeRepresentation_3();

    if (temp == 0) return null;
    return (vtkTensorProbeRepresentation)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void CreateDefaultRepresentation_4();
  public void CreateDefaultRepresentation()
    { CreateDefaultRepresentation_4(); }

  public vtkTensorProbeWidget() { super(); }

  public vtkTensorProbeWidget(long id) { super(id); }
  public native long   VTKInit();

}
